@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.h,v 1.10 2000/02/13 16:24:01 bazsi Exp $
+ * $Id: affile.h,v 1.10.2.1 2000/06/23 12:54:06 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -51,8 +51,10 @@ void affile_set_encrypt(struct log_dest_driver *affile, int enable);
 void affile_set_owner(struct log_dest_driver *c, char *owner);
 void affile_set_group(struct log_dest_driver *c, char *group);
 void affile_set_perm(struct log_dest_driver *c, int perm);
-void affile_set_create_dirs(struct log_dest_driver *c, int enable);
+void affile_set_dir_owner(struct log_dest_driver *c, char *owner);
+void affile_set_dir_group(struct log_dest_driver *c, char *group);
 void affile_set_dir_perm(struct log_dest_driver *c, int perm);
+void affile_set_create_dirs(struct log_dest_driver *c, int enable);
 
 struct log_source_driver *make_affile_source(const char *name, int flags);
 struct log_dest_driver *make_affile_dest(const char *name, int flags);
