@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: center.c,v 1.12 1999/11/20 19:13:39 bazsi Exp $
+ * $Id: center.c,v 1.13 2000/02/13 15:29:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -112,7 +112,7 @@ static void do_distribute_log(struct log_handler *c, struct log_info *msg)
 		for (d = def_connection->nodes; d; d = d->next) {
 			if (d->type == EP_DESTINATION) {
 				assert(d->ref);
-				HANDLE_LOG(d->ref, msg);
+				HANDLE_LOG(d->ref, log_info_use(msg));
 			}
 		}
 	}
