@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.26.2.2 2000/06/23 12:54:06 bazsi Exp $
+ * $Id: main.c,v 1.26.2.3 2000/08/22 08:38:57 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -194,7 +194,7 @@ void go_background()
 	if (pid == 0) {
 		int fd = open(pidfilename, O_CREAT | O_WRONLY | O_NOCTTY | O_TRUNC, 0600);
 		if (fd != -1) {
-			struct ol_string *pid_s = c_format("%i", getpid());
+			struct ol_string *pid_s = c_format("%i\n", getpid());
 			write(fd, pid_s->data, pid_s->length);
 			ol_string_free(pid_s);
 			close(fd);
@@ -273,7 +273,7 @@ int main(int argc, char **argv)
 			break;
 		case 'V':
 			werror(PACKAGE " " VERSION "\n");
-			break;
+			return 0;
 #ifdef YYDEBUG
 		case 'y':
 			yydebug = 1;
